@@ -46,3 +46,9 @@ class KernelCIViewsExtension(LavaServerExtension):
     @property
     def version(self):
         return versiontools.format_version(lava_kernel_ci_views_app.__version__)
+
+    def contribute_to_settings(self, settings_module):
+        super(KernelCIViewsExtension, self).contribute_to_settings(settings_module)
+        prepend_label_apps = settings_module.get('STATICFILES_PREPEND_LABEL_APPS', [])
+        if self.app_name in prepend_label_apps:
+            prepend_label_apps.remove(self.app_name)
