@@ -19,3 +19,14 @@
 from django.db import models
 
 # Create your models here.
+
+class BoardType(models.Model):
+
+    slug = models.SlugField()
+
+    display_name = models.TextField()
+
+    icon = models.FileField(upload_to="board_icons")
+
+    def __unicode__(self):
+        return "%s board type" % self.slug
