@@ -21,4 +21,7 @@ from django.conf.urls.defaults import url, patterns
 urlpatterns = patterns(
     'lava_kernel_ci_views_app.views',
     url(r'index$', 'index'),
+    url(r'compile$', 'compile_view'),
+    url(r'per_board/(?P<board_type>[a-zA-Z0-9_]+)$', 'per_board'),
+    url(r'board_icon/(?P<board_type>[a-zA-Z0-9_]+)$', 'board_icon'),
     )
